@@ -9,14 +9,6 @@
 #
 ######################################################################
 # Der Standardbenutzer ist admin mit dem Standardkennwort admin
-#---------------------------------------------------------------------
-# Um OPList in Oracle zu installieren ist das Oracle-Setup-Skript
-# aus zu fuehren:
-# create-oracle-db-modell
-#---------------------------------------------------------------------
-# Um OPList in MySQL zu installieren ist das MySQL-Setup-Skript
-# aus zu fuehren:
-# create-mysql-db-modell.sql
 ######################################################################
 ####  History
 #---------------------------------------------------------------------
@@ -76,6 +68,8 @@ $connection = null;
 $mode = "";
 # output
 $tmpHTML = "";
+#
+$debugMeConstant = 0;
 ######################################################################
 
 $header = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN">
@@ -88,7 +82,7 @@ $header = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN">
     <body link="#0000FF" vlink="#0000FF">
     <div class="header"><img src="img/logo.jpg" width=114 height=48 border=0 alt="OPList">';
 
-$footer = '</div><div class="footer"><small>&copy; 2011 by <a href="http://software.glawar.at/oplist/" target="_blank">OPList</a> v1.6.2 (2014-07-21)</small></div></body></html>';
+$footer = '</div><div class="footer"><small>&copy; 2011 by <a href="http://software.glawar.at/oplist/" target="_blank">OPList</a> v1.7.523 (2014-07-30)</small></div></body></html>';
 
 
 session_start();
@@ -99,6 +93,15 @@ session_start();
 #session_destroy();
 
 
+function debugMe($debugText){
+    global $debugMeConstant;
+
+    if ($debugMeConstant == 1) {
+        echo $debugText;
+    }
+}
+
+
 #---------------------------------------------------------------------
 # (c) www.glawar.at: liefert in Abhaengigkeit der obigen Parameter in
 #                    $connection eine gueltige Datenbankverbindung
@@ -397,9 +400,9 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         <script src='sort.js'></script>
         <div class='menuBar'>";
 
-    if (isset($_SESSION['OPGID']) && $_SESSION['OPGID'] != "2") {
+    #if (isset($_SESSION['OPGID']) && $_SESSION['OPGID'] != "2") {
         $header .= "<a class='menuitem' title='Meine OP-Punke' href='javascript:ajx(\"userlist\");'><img src='img/home.png' width=32 height=32 border=0 hspace=10 alt='Meine OP-Punkte'></a>";
-    }
+    #}
 
     $header .= "<a class='menuitem' title='Alle OP-Punke' href='javascript:ajx(\"list\")'><img hspace=10 src='img/list.png' width=32 height=32 border=0 alt='Alle OP-Punke'></a>";
 
@@ -681,25 +684,32 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         $result = getRessource($sQuery);
         echo getError();
         freeRessource($result);
+        #debugMe("I am the debug Tester");
+        debugMe("<p>mailModus <b>".$mailModus."</b></p>");
+        debugMe("<p>debugMail <b>".$debugMail."</b></p>");
+        debugMe("<p>debugSQL <b>".$debugSQL."</b></p>");
         if ($mailModus == 1 || $mailModus == 2) {
             # wir schicken den Betroffenen eine Email
             $email['FROMMAIL'] = getEmailOfId ($_SESSION['OPUID']);
             $email['SUBJECT'] = $projectName." - Neuer OP-Punkt: ".$_POST['OPENTRY'];
-            $email['MSG'] = "Der OP-Punkt\n\n".$_POST['OPENTRY']."\n\n\nwurde hinzugefuegt.";
+            $email['MSG'] = "Der OP-Punkt\n\n".$_POST['OPENTRY']."\n\nwurde hinzugefuegt.";
             $email['HEADERS'] = "Return-path: ".$email['FROMMAIL']."\n";
             $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
             $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
             $sQuery = "SELECT DISTINCT OPUEMAIL FROM OPLIST_USERS WHERE (OPUID in (".$OPUID_ASSIGNED.") OR (OPGID = ".$mailGroup.")) AND OPUACTIVE = 1 AND OPUEMAIL IS NOT NULL AND OPUID != ".$_SESSION['OPUID'];
             if ($debugSQL == 1) {
-                echo "<p><b>Emails-Select:</b>".$sQuery."</p>";
+                echo "<p><b>Emails-Select for Inserting new OP entry:</b>".$sQuery."</p>";
             }
             $result = getRessource($sQuery);
             echo getError();
             while ($val = getRow($result)) {
+                debugMe("<p>email <b>".$val['OPUEMAIL']."</b></p>");
                 $email['TOMAIL'] = $val['OPUEMAIL'];
                 if ($debugMail == 1) {
+                    debugMe("<p>Entry Debug</p>");
                     debugIntoDB ($email['TOMAIL']."|".$email['SUBJECT']."|".$email['MSG']."|".$email['HEADERS']);
                 } else {
+                    debugMe("<p>Enailing</p>");
                     @mail($email['TOMAIL'], $email['SUBJECT'], $email['MSG'], $email['HEADERS']);
                 }
             }
@@ -754,10 +764,6 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             $newFileName = "null";
         }
 
-
-
-
-
         $sQuery = "INSERT INTO OPLIST_COMMENT (OPCID, OPUID, OPCTEXT, OPID, OPCPRIVATE, OPCFILENAME) VALUES (".$nextId.", ".$_SESSION['OPUID'].", '".$_POST["OPCTEXT"]."', ".$_POST["OPID"].", ".$OPCPRIVATE.", ".$newFileName.")";
         if ($debugSQL == 1) {
             echo "<p><b>Insert-Kommentar:</b>".$sQuery."</p>";
@@ -781,6 +787,54 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         freeRessource($result);
 
 
+        if ($mailModus == 1) {
+            $sendMail = 0;
+            debugMe("<p>Oeffentlicher Eintrag (0) <b>".$OPCPRIVATE."</b></p>");
+            if ($OPCPRIVATE == 0) {
+                debugMe("<p>OP erhaelt einen oeffentlichen Kommentar --> Email an Eigentümer</b></p>");
+                # Email an OP-Ersteller
+                #echo "Email an Eigentuemer";
+                $sendMail = 1;
+                $tempFromEmail = $_SESSION['OPUID'];
+                $email['FROMMAIL'] = getEmailOfId ($_SESSION['OPUID']);
+                $sQuery = "SELECT OPUID_ASSIGNED, OPUID_CREATED, OPENTRY FROM OPLIST WHERE OPID = ".$_POST['OPID'];
+                if ($debugSQL == 1) {
+                    echo "<p><b>Select:</b>".$sQuery."</p>";
+                }
+                $result = getRessource($sQuery);
+                echo getError();
+                while ($rows = getRow($result )) {
+                    $assigned = $rows['OPUID_ASSIGNED'];
+                    $oldUIdCreated = $rows['OPUID_CREATED'];
+                    $opEntry = $rows['OPENTRY'];
+                }
+                freeRessource($result);
+                $tempToMail = $oldUIdCreated;
+            }
+            if ($sendMail == 1) {
+                $email['SUBJECT'] = $projectName." - Neuer Kommentar zu OP-Punk: ".$_POST['OPID']."-".$opEntry;
+                $email['MSG'] = "Der OP-Punkt\n\n".$_POST['OPID']."-".$opEntry."\n\nerhielt einen neuen Kommentar.\n\n\n".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"]."\n\n\n\n".$_POST["OPCTEXT"];
+                $email['HEADERS'] = "Return-path: ".$email['FROMMAIL']."\n";
+                $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
+                $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
+                $sQuery = "SELECT DISTINCT OPUEMAIL FROM OPLIST_USERS WHERE (OPUID in (".$tempToMail.",".$assigned.") OR (OPGID = ".$mailGroup.")) AND OPUACTIVE = 1 AND OPUEMAIL IS NOT NULL AND OPUID != ".$_SESSION['OPUID'];
+                if ($debugSQL == 1) {
+                    echo "<p><b>Select:</b>".$sQuery."</p>";
+                }
+                $result = getRessource($sQuery);
+                echo getError();
+                while ($val = getRow($result)) {
+                    $email['TOMAIL'] = $val['OPUEMAIL'];
+                    if ($debugMail == 1) {
+                        debugIntoDB ($email['TOMAIL']."|".$email['SUBJECT']."|".$email['MSG']."|".$email['HEADERS']);
+                    } else {
+                        @mail($email['TOMAIL'], $email['SUBJECT'], $email['MSG'], $email['HEADERS']);
+                    }
+                }
+                freeRessource($result);
+            }
+        }
+
         if ($mailModus == 2) {
             # wir schicken immer eime Email
             $sQuery = "SELECT OPUID_ASSIGNED, OPENTRY, OPUID_CREATED FROM OPLIST WHERE OPDELETED = 0 AND OPID = ".$_POST["OPID"];
@@ -802,7 +856,7 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
 
             $email['FROMMAIL'] = getEmailOfId ($_SESSION['OPUID']);
             $email['SUBJECT'] = $projectName." - Update OP-Punk: ".$OPName;
-            $email['MSG'] = "Der OP-Punkt\n\n".$OPName."\n\n\nwurde aktualisiert.\n\n".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"];
+            $email['MSG'] = "Der OP-Punkt\n\n".$OPName."\n\nwurde aktualisiert.\n\n\n".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"];
             $email['HEADERS'] = "Return-path: ".$email['FROMMAIL']."\n";
             $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
             $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
@@ -850,7 +904,7 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         $oldBugStatus = 0;
         $sQuery = "SELECT OPSID, OPUID_CREATED, OPUID_ASSIGNED FROM OPLIST WHERE OPID = ".$_POST['OPID'];
         if ($debugSQL == 1) {
-            echo "<p><b>Email-Select:</b>".$sQuery."</p>";
+            echo "<p><b>Select:</b>".$sQuery."</p>";
         }
         $result = getRessource($sQuery);
         echo getError();
@@ -890,31 +944,39 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
 
         if ($mailModus == 1) {
             $sendMail = 0;
+            debugMe("<p>New Assigned to <b>".$_POST['OPUID_ASSIGNED']."</b></p>");
+            debugMe("<p>New OP-Status <b>".$_POST['OPSID']."</b></p>");
+            debugMe("<p>oldUIdAssigned <b>".$oldUIdAssigned."</b></p>");
+            debugMe("<p>oldOPStatus <b>".$oldBugStatus."</b></p>");
             if ($oldUIdAssigned == 0 && $_POST['OPUID_ASSIGNED'] != 0) {
+                debugMe("<p>OP war nicht zugewiesen und ist nun zugewiesen --> Email an zugewiesenen IBN</b></p>");
                 # Email an zugewiesenen IBN
                 #echo "Email an IBN";
-                $sendMail = 1;#
+                $sendMail = 1;
                 $tempFromEmail = $oldUIdCreated;
                 $email['FROMMAIL'] = getEmailOfId ($oldUIdCreated);
                 $tempToMail = $_POST['OPUID_ASSIGNED'];
             } else if (($oldBugStatus == 1 || $oldBugStatus == 2) && $_POST['OPSID'] == 3) {
+                debugMe("<p>OP hatte Status offen oder in Bearbeitung und wechselt nun zu erledigt --> Email an OP-Eigentümer</b></p>");
                 # Email an OP-Ersteller
                 #echo "Email an Eigentuemer";
                 $sendMail = 1;
                 $tempFromEmail = $_SESSION['OPUID'];
                 $email['FROMMAIL'] = getEmailOfId ($_SESSION['OPUID']);
                 $tempToMail = $oldUIdCreated;
-            } else if ((($oldBugStatus == 3 || $oldBugStatus == 4) && $_POST['OPSID'] != $oldBugStatus) || (($oldBugStatus == 1 || $oldBugStatus == 2) && $_POST['OPSID'] == 4))  {
+            } else if ((($oldBugStatus == 3 || $oldBugStatus == 4) && $_POST['OPSID'] != $oldBugStatus) || (($oldBugStatus == 1 || $oldBugStatus == 2 || $oldBugStatus == 3) && $_POST['OPSID'] == 4))  {
+                debugMe("<p>OP hatte Status erledigt oder abgeschlossen und der Status wurde auf offen oder in Bearbeitung gestellt --> Email an zugewiesenen IBN</b></p>");
+                debugMe("<p>oder: OP hatte Status offen, in Bearbeitung oder erledigt und wird auf Status abgeschlossen gedreht --> Email an IBN </b></p>");
                 # Email an zugewiesenen IBN
                 #echo "Email an IBN2";
-                $sendMail = 1;#
+                $sendMail = 1;
                 $tempFromEmail = $oldUIdCreated;
                 $email['FROMMAIL'] = getEmailOfId ($oldUIdCreated);
                 $tempToMail = $_POST['OPUID_ASSIGNED'];
             }
             if ($sendMail == 1) {
-                $email['SUBJECT'] = $projectName." - Update OP-Punk: ".$_POST['OPENTRY'];
-                $email['MSG'] = "Der OP-Punkt\n\n".$_POST['OPENTRY']."\n\n\nwurde aktualisiert.\n\n".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"];
+                $email['SUBJECT'] = $projectName." - Update OP-Punk: ".$_POST['OPID']."-".$_POST['OPENTRY'];
+                $email['MSG'] = "Der OP-Punkt\n\n".$_POST['OPID']."-".$_POST['OPENTRY']."\n\nwurde aktualisiert.\n\n\n".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"];
                 $email['HEADERS'] = "Return-path: ".$email['FROMMAIL']."\n";
                 $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
                 $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
@@ -937,7 +999,7 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         } else if ($mailModus == 2) {
             $email['FROMMAIL'] = getEmailOfId ($oldUIdCreated);
             $email['SUBJECT'] = $projectName." - Update OP-Punk: ".$_POST['OPENTRY'];
-            $email['MSG'] = "Der OP-Punkt\n\n".$_POST['OPENTRY']."\n\n\nwurde aktualisiert.\n\n".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"];
+            $email['MSG'] = "Der OP-Punkt\n\n".$_POST['OPENTRY']."\n\nwurde aktualisiert.\n\n\n".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"];
             $email['HEADERS'] = "Return-path: ".$email['FROMMAIL']."\n";
             $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
             $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
@@ -996,26 +1058,37 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         $afterToChar = ", 'DD.MM.YYYY HH24:MI')";
     }
 
-    $sQuery = "SELECT OP.OPID, OP.OPSID, OPS.OPSTEXT, OP.OPPRIO, OPA.OPATEXT, OPP.OPPTEXT, OP.OPENTRY, ".$beforeToChar."OP.OPDATECREATED".$afterToChar." OPDATECREATED, ".$beforeToChar."OP.OPDATEUPDATED".$afterToChar." OPDATEUPDATED, OP.OPUID_ASSIGNED, OPUU.OPUUSERNAME UPDATEDUSER, OP.OPAID, OP.OPPID, OPUA.OPUUSERNAME ASSIGNEDUSER
-FROM OPLIST OP, OPLIST_AREA OPA, OPLIST_PRODUCT OPP, OPLIST_STAT OPS, OPLIST_USERS OPUU, OPLIST_USERS OPUA
+    $sQuery = "SELECT OP.OPID, OP.OPSID, OPUC.OPUUSERNAME CREATEDUSER, OPS.OPSTEXT, OP.OPPRIO, OPA.OPATEXT, OPP.OPPTEXT, OP.OPENTRY, ".$beforeToChar."OP.OPDATECREATED".$afterToChar." OPDATECREATED, ".$beforeToChar."OP.OPDATEUPDATED".$afterToChar." OPDATEUPDATED, OP.OPUID_ASSIGNED, OPUU.OPUUSERNAME UPDATEDUSER, OP.OPAID, OP.OPPID, OPUA.OPUUSERNAME ASSIGNEDUSER
+FROM OPLIST OP, OPLIST_AREA OPA, OPLIST_PRODUCT OPP, OPLIST_STAT OPS, OPLIST_USERS OPUU, OPLIST_USERS OPUC, OPLIST_USERS OPUA
 WHERE OPA.OPAID = OP.OPAID
     AND OPP.OPPID = OP.OPPID
     AND OPS.OPSID = OP.OPSID
     AND OPUU.OPUID = OP.OPUID_UPDATED
     AND OP.OPDELETED = 0
+    AND OP.OPUID_CREATED = OPUC.OPUID
     AND OPUA.OPUID = OP.OPUID_ASSIGNED".$tempFilter."
 ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED DESC";
 
     if (!empty($_GET['mode']) && $_GET['mode'] == "userlist") {
-        $sQuery = "SELECT OP.OPID, OP.OPSID, OPS.OPSTEXT, OP.OPPRIO, OPA.OPATEXT, OPP.OPPTEXT, OP.OPENTRY, ".$beforeToChar."OP.OPDATECREATED".$afterToChar." OPDATECREATED, ".$beforeToChar."OP.OPDATEUPDATED".$afterToChar." OPDATEUPDATED, OP.OPUID_ASSIGNED, OPUU.OPUUSERNAME UPDATEDUSER, OP.OPAID, OP.OPPID, OPUA.OPUUSERNAME ASSIGNEDUSER
-FROM OPLIST OP, OPLIST_AREA OPA, OPLIST_PRODUCT OPP, OPLIST_STAT OPS, OPLIST_USERS OPUU, OPLIST_USERS OPUA
+        if ($_SESSION['OPGID'] == '2') {
+            # wir sind Kunde
+            $groupFilter=" AND OP.OPUID_CREATED = '".$_SESSION['OPUID']."'";
+        } else if ($_SESSION['OPGID'] == '3') {
+            # wir sind IBN
+            $groupFilter=" AND OP.OPUID_ASSIGNED = '".$_SESSION['OPUID']."'";
+        } else {
+            # wir sind SYS oder Admin
+            $groupFilter=" AND OP.OPUID_ASSIGNED = '".$_SESSION['OPUID']."'";
+        }
+        $sQuery = "SELECT OP.OPID, OP.OPSID, OPUC.OPUUSERNAME CREATEDUSER, OPS.OPSTEXT, OP.OPPRIO, OPA.OPATEXT, OPP.OPPTEXT, OP.OPENTRY, ".$beforeToChar."OP.OPDATECREATED".$afterToChar." OPDATECREATED, ".$beforeToChar."OP.OPDATEUPDATED".$afterToChar." OPDATEUPDATED, OP.OPUID_ASSIGNED, OPUU.OPUUSERNAME UPDATEDUSER, OP.OPAID, OP.OPPID, OPUA.OPUUSERNAME ASSIGNEDUSER
+FROM OPLIST OP, OPLIST_AREA OPA, OPLIST_PRODUCT OPP, OPLIST_STAT OPS, OPLIST_USERS OPUU, OPLIST_USERS OPUC, OPLIST_USERS OPUA
 WHERE OPA.OPAID = OP.OPAID
     AND OPP.OPPID = OP.OPPID
     AND OPS.OPSID = OP.OPSID
     AND OPUU.OPUID = OP.OPUID_UPDATED
     AND OP.OPDELETED = 0
-    AND OPUA.OPUID = OP.OPUID_ASSIGNED".$tempFilter."
-    AND OP.OPUID_ASSIGNED = '".$_SESSION['OPUID']."'
+    AND OP.OPUID_CREATED = OPUC.OPUID
+    AND OPUA.OPUID = OP.OPUID_ASSIGNED".$tempFilter.$groupFilter."
 ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED DESC";
     }
     if ($debugSQL == 1) {
@@ -1078,8 +1151,6 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
         $result = getRessource($sQuery);
     }*/
 
-
-
     if ($mode == "del") {
         $tmpHTML .= "Eintrag gel&ouml;scht.";
     } else if ($mode == "comment") {
@@ -1124,7 +1195,7 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
             </tr>';
 
         if ($_SESSION['OPGID'] == "2") {
-            $tempSQL = " and opc.opcprivate = 0";
+            $tempSQL = " AND OPC.OPCPRIVATE = 0";
         } else {
             $tempSQL = "";
         }
@@ -1365,6 +1436,7 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
                 <td valign=top style="width:40px;">&nbsp;</td>
                 <td valign=top style="width:30px; font-size:10px;">Nr.</td>
                 <td valign=top style="width:*; font-size:10px;">Titel</td>
+                <td valign=top style="width:100px; font-size:10px;">angelegt</td>
                 <td valign=top style="width:100px; font-size:10px;">Status</td>
                 <td valign=top style="width:50px; font-size:10px;">Prio</td>
                 <td valign=top style="width:70px; font-size:10px;">Bereich</td>
@@ -1397,6 +1469,7 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
 
             $tmpHTML .=  "</td><td valign='top' style='font-size:10px;'>".$v['OPID']."</td>
             <td valign='top' style='font-size:10px;'><a href='" .$_SERVER['PHP_SELF'] . "?mode=comment&OPID=".$v['OPID']."'>".$v['OPENTRY']."</a></td>
+                  <td valign='top' style='font-size:10px;'>".$v['CREATEDUSER']."</td>
                   <td valign='top' style='font-size:10px;'>".$v['OPSTEXT']."</td>
                   <td valign='top' style='font-size:10px;'>".$prioArr[$v['OPPRIO']] . "</td>
                   <td valign='top' style='font-size:10px;'>".$v['OPATEXT']."</td>
